# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LookupContractDomain(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("contract_id",)
        CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        contract_id: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, contract_id: _Optional[_Iterable[str]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("results",)
        class ResultsEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        RESULTS_FIELD_NUMBER: _ClassVar[int]
        results: _containers.ScalarMap[str, str]
        def __init__(self, results: _Optional[_Mapping[str, str]] = ...) -> None: ...
    def __init__(self) -> None: ...

class LookupTransactionDomain(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("transaction_id",)
        TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
        transaction_id: str
        def __init__(self, transaction_id: _Optional[str] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("domain_id",)
        DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
        domain_id: str
        def __init__(self, domain_id: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class LookupOffsetByTime(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("timestamp",)
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        timestamp: _timestamp_pb2.Timestamp
        def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("offset",)
        OFFSET_FIELD_NUMBER: _ClassVar[int]
        offset: str
        def __init__(self, offset: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class LookupOffsetByIndex(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("index",)
        INDEX_FIELD_NUMBER: _ClassVar[int]
        index: int
        def __init__(self, index: _Optional[int] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("offset",)
        OFFSET_FIELD_NUMBER: _ClassVar[int]
        offset: str
        def __init__(self, offset: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class CountInFlight(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("domain_id",)
        DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
        domain_id: str
        def __init__(self, domain_id: _Optional[str] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("pending_submissions", "pending_transactions")
        PENDING_SUBMISSIONS_FIELD_NUMBER: _ClassVar[int]
        PENDING_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
        pending_submissions: int
        pending_transactions: int
        def __init__(self, pending_submissions: _Optional[int] = ..., pending_transactions: _Optional[int] = ...) -> None: ...
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import ledger_offset_pb2 as _ledger_offset_pb2
from . import transaction_filter_pb2 as _transaction_filter_pb2
from . import transaction_pb2 as _transaction_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetTransactionsRequest(_message.Message):
    __slots__ = ("ledger_id", "begin", "end", "filter", "verbose", "send_pruned_offsets")
    LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    BEGIN_FIELD_NUMBER: _ClassVar[int]
    END_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    SEND_PRUNED_OFFSETS_FIELD_NUMBER: _ClassVar[int]
    ledger_id: str
    begin: _ledger_offset_pb2.LedgerOffset
    end: _ledger_offset_pb2.LedgerOffset
    filter: _transaction_filter_pb2.TransactionFilter
    verbose: bool
    send_pruned_offsets: bool
    def __init__(self, ledger_id: _Optional[str] = ..., begin: _Optional[_Union[_ledger_offset_pb2.LedgerOffset, _Mapping]] = ..., end: _Optional[_Union[_ledger_offset_pb2.LedgerOffset, _Mapping]] = ..., filter: _Optional[_Union[_transaction_filter_pb2.TransactionFilter, _Mapping]] = ..., verbose: bool = ..., send_pruned_offsets: bool = ...) -> None: ...

class GetTransactionsResponse(_message.Message):
    __slots__ = ("transactions", "pruned_offset")
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    PRUNED_OFFSET_FIELD_NUMBER: _ClassVar[int]
    transactions: _containers.RepeatedCompositeFieldContainer[_transaction_pb2.Transaction]
    pruned_offset: str
    def __init__(self, transactions: _Optional[_Iterable[_Union[_transaction_pb2.Transaction, _Mapping]]] = ..., pruned_offset: _Optional[str] = ...) -> None: ...

class GetTransactionTreesResponse(_message.Message):
    __slots__ = ("transactions", "pruned_offset")
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    PRUNED_OFFSET_FIELD_NUMBER: _ClassVar[int]
    transactions: _containers.RepeatedCompositeFieldContainer[_transaction_pb2.TransactionTree]
    pruned_offset: str
    def __init__(self, transactions: _Optional[_Iterable[_Union[_transaction_pb2.TransactionTree, _Mapping]]] = ..., pruned_offset: _Optional[str] = ...) -> None: ...

class GetTransactionByEventIdRequest(_message.Message):
    __slots__ = ("ledger_id", "event_id", "requesting_parties")
    LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    REQUESTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    ledger_id: str
    event_id: str
    requesting_parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ledger_id: _Optional[str] = ..., event_id: _Optional[str] = ..., requesting_parties: _Optional[_Iterable[str]] = ...) -> None: ...

class GetTransactionByIdRequest(_message.Message):
    __slots__ = ("ledger_id", "transaction_id", "requesting_parties")
    LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    REQUESTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    ledger_id: str
    transaction_id: str
    requesting_parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ledger_id: _Optional[str] = ..., transaction_id: _Optional[str] = ..., requesting_parties: _Optional[_Iterable[str]] = ...) -> None: ...

class GetTransactionResponse(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.TransactionTree
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.TransactionTree, _Mapping]] = ...) -> None: ...

class GetFlatTransactionResponse(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.Transaction
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.Transaction, _Mapping]] = ...) -> None: ...

class GetLedgerEndRequest(_message.Message):
    __slots__ = ("ledger_id",)
    LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    ledger_id: str
    def __init__(self, ledger_id: _Optional[str] = ...) -> None: ...

class GetLedgerEndResponse(_message.Message):
    __slots__ = ("offset",)
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    offset: _ledger_offset_pb2.LedgerOffset
    def __init__(self, offset: _Optional[_Union[_ledger_offset_pb2.LedgerOffset, _Mapping]] = ...) -> None: ...

class GetLatestPrunedOffsetsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLatestPrunedOffsetsResponse(_message.Message):
    __slots__ = ("participant_pruned_up_to_inclusive", "all_divulged_contracts_pruned_up_to_inclusive")
    PARTICIPANT_PRUNED_UP_TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    ALL_DIVULGED_CONTRACTS_PRUNED_UP_TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    participant_pruned_up_to_inclusive: _ledger_offset_pb2.LedgerOffset
    all_divulged_contracts_pruned_up_to_inclusive: _ledger_offset_pb2.LedgerOffset
    def __init__(self, participant_pruned_up_to_inclusive: _Optional[_Union[_ledger_offset_pb2.LedgerOffset, _Mapping]] = ..., all_divulged_contracts_pruned_up_to_inclusive: _Optional[_Union[_ledger_offset_pb2.LedgerOffset, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import common_pb2 as _common_pb2
from . import confirmation_response_pb2 as _confirmation_response_pb2
from . import merkle_pb2 as _merkle_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.rpc import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InformeeTree(_message.Message):
    __slots__ = ("tree",)
    TREE_FIELD_NUMBER: _ClassVar[int]
    tree: _merkle_pb2.GenTransactionTree
    def __init__(self, tree: _Optional[_Union[_merkle_pb2.GenTransactionTree, _Mapping]] = ...) -> None: ...

class ParticipantReject(_message.Message):
    __slots__ = ("reasons",)
    REASONS_FIELD_NUMBER: _ClassVar[int]
    reasons: _containers.RepeatedCompositeFieldContainer[RejectionReason]
    def __init__(self, reasons: _Optional[_Iterable[_Union[RejectionReason, _Mapping]]] = ...) -> None: ...

class RejectionReason(_message.Message):
    __slots__ = ("parties", "reject")
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    REJECT_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    reject: _confirmation_response_pb2.LocalVerdict
    def __init__(self, parties: _Optional[_Iterable[str]] = ..., reject: _Optional[_Union[_confirmation_response_pb2.LocalVerdict, _Mapping]] = ...) -> None: ...

class MediatorReject(_message.Message):
    __slots__ = ("reason", "is_malformed")
    REASON_FIELD_NUMBER: _ClassVar[int]
    IS_MALFORMED_FIELD_NUMBER: _ClassVar[int]
    reason: _status_pb2.Status
    is_malformed: bool
    def __init__(self, reason: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., is_malformed: bool = ...) -> None: ...

class Verdict(_message.Message):
    __slots__ = ("approve", "participant_reject", "mediator_reject")
    APPROVE_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_REJECT_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_REJECT_FIELD_NUMBER: _ClassVar[int]
    approve: _empty_pb2.Empty
    participant_reject: ParticipantReject
    mediator_reject: MediatorReject
    def __init__(self, approve: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., participant_reject: _Optional[_Union[ParticipantReject, _Mapping]] = ..., mediator_reject: _Optional[_Union[MediatorReject, _Mapping]] = ...) -> None: ...

class ConfirmationResultMessage(_message.Message):
    __slots__ = ("domain_id", "view_type", "request_id", "root_hash", "verdict", "informees")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_TYPE_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    ROOT_HASH_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    INFORMEES_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    view_type: _common_pb2.ViewType
    request_id: int
    root_hash: bytes
    verdict: Verdict
    informees: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, domain_id: _Optional[str] = ..., view_type: _Optional[_Union[_common_pb2.ViewType, str]] = ..., request_id: _Optional[int] = ..., root_hash: _Optional[bytes] = ..., verdict: _Optional[_Union[Verdict, _Mapping]] = ..., informees: _Optional[_Iterable[str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import offset_checkpoint_pb2 as _offset_checkpoint_pb2
from . import reassignment_pb2 as _reassignment_pb2
from . import transaction_pb2 as _transaction_pb2
from . import transaction_filter_pb2 as _transaction_filter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetUpdatesRequest(_message.Message):
    __slots__ = ("begin_exclusive", "end_inclusive", "filter", "verbose")
    BEGIN_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    END_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    begin_exclusive: int
    end_inclusive: int
    filter: _transaction_filter_pb2.TransactionFilter
    verbose: bool
    def __init__(self, begin_exclusive: _Optional[int] = ..., end_inclusive: _Optional[int] = ..., filter: _Optional[_Union[_transaction_filter_pb2.TransactionFilter, _Mapping]] = ..., verbose: bool = ...) -> None: ...

class GetUpdatesResponse(_message.Message):
    __slots__ = ("transaction", "reassignment", "offset_checkpoint")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_CHECKPOINT_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.Transaction
    reassignment: _reassignment_pb2.Reassignment
    offset_checkpoint: _offset_checkpoint_pb2.OffsetCheckpoint
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.Transaction, _Mapping]] = ..., reassignment: _Optional[_Union[_reassignment_pb2.Reassignment, _Mapping]] = ..., offset_checkpoint: _Optional[_Union[_offset_checkpoint_pb2.OffsetCheckpoint, _Mapping]] = ...) -> None: ...

class GetUpdateTreesResponse(_message.Message):
    __slots__ = ("transaction_tree", "reassignment", "offset_checkpoint")
    TRANSACTION_TREE_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_CHECKPOINT_FIELD_NUMBER: _ClassVar[int]
    transaction_tree: _transaction_pb2.TransactionTree
    reassignment: _reassignment_pb2.Reassignment
    offset_checkpoint: _offset_checkpoint_pb2.OffsetCheckpoint
    def __init__(self, transaction_tree: _Optional[_Union[_transaction_pb2.TransactionTree, _Mapping]] = ..., reassignment: _Optional[_Union[_reassignment_pb2.Reassignment, _Mapping]] = ..., offset_checkpoint: _Optional[_Union[_offset_checkpoint_pb2.OffsetCheckpoint, _Mapping]] = ...) -> None: ...

class GetTransactionByEventIdRequest(_message.Message):
    __slots__ = ("event_id", "requesting_parties")
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    REQUESTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    requesting_parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, event_id: _Optional[str] = ..., requesting_parties: _Optional[_Iterable[str]] = ...) -> None: ...

class GetTransactionByIdRequest(_message.Message):
    __slots__ = ("update_id", "requesting_parties")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    REQUESTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    requesting_parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, update_id: _Optional[str] = ..., requesting_parties: _Optional[_Iterable[str]] = ...) -> None: ...

class GetTransactionTreeResponse(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.TransactionTree
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.TransactionTree, _Mapping]] = ...) -> None: ...

class GetTransactionResponse(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.Transaction
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.Transaction, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v2/synchronization.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v2/synchronization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..v0 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transaction__pb2
from ..v0 import synchronization_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_synchronization__pb2
from ..v0 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__pb2
from ..v1 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_participant__transaction__pb2
from ..v1 import participant_transfer_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_participant__transfer__pb2
from ..v1 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_topology__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9com/digitalasset/canton/protocol/v2/synchronization.proto\x12#com.digitalasset.canton.protocol.v2\x1a\x41\x63om/digitalasset/canton/protocol/v0/participant_transaction.proto\x1a\x39\x63om/digitalasset/canton/protocol/v0/synchronization.proto\x1a\x32\x63om/digitalasset/canton/protocol/v0/topology.proto\x1a\x41\x63om/digitalasset/canton/protocol/v1/participant_transaction.proto\x1a>com/digitalasset/canton/protocol/v1/participant_transfer.proto\x1a\x32\x63om/digitalasset/canton/protocol/v1/topology.proto\"\xae\t\n\x0f\x45nvelopeContent\x12\x61\n\x10informee_message\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v1.InformeeMessageH\x00R\x0finformeeMessage\x12\x63\n\x0esigned_message\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v0.SignedProtocolMessageH\x00R\rsignedMessage\x12q\n\x16\x65ncrypted_view_message\x18\x03 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v1.EncryptedViewMessageH\x00R\x14\x65ncryptedViewMessage\x12\x96\x01\n#domain_topology_transaction_message\x18\x05 \x01(\x0b\x32\x45.com.digitalasset.canton.protocol.v1.DomainTopologyTransactionMessageH\x00R domainTopologyTransactionMessage\x12\x84\x01\n\x1dtransfer_out_mediator_message\x18\x06 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v1.TransferOutMediatorMessageH\x00R\x1atransferOutMediatorMessage\x12\x81\x01\n\x1ctransfer_in_mediator_message\x18\x07 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v1.TransferInMediatorMessageH\x00R\x19transferInMediatorMessage\x12\x62\n\x11root_hash_message\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v0.RootHashMessageH\x00R\x0frootHashMessage\x12\x9c\x01\n%register_topology_transaction_request\x18\t \x01(\x0b\x32G.com.digitalasset.canton.protocol.v0.RegisterTopologyTransactionRequestH\x00R\"registerTopologyTransactionRequest\x12\x9f\x01\n&register_topology_transaction_response\x18\n \x01(\x0b\x32H.com.digitalasset.canton.protocol.v1.RegisterTopologyTransactionResponseH\x00R#registerTopologyTransactionResponseB\x17\n\x15some_envelope_contentBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v2.synchronization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2'
  _globals['_ENVELOPECONTENT']._serialized_start=460
  _globals['_ENVELOPECONTENT']._serialized_end=1658
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from .. import commands_pb2 as _commands_pb2
from .. import completion_pb2 as _completion_pb2
from .. import value_pb2 as _value_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommandState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    COMMAND_STATE_UNSPECIFIED: _ClassVar[CommandState]
    COMMAND_STATE_PENDING: _ClassVar[CommandState]
    COMMAND_STATE_SUCCEEDED: _ClassVar[CommandState]
    COMMAND_STATE_FAILED: _ClassVar[CommandState]
COMMAND_STATE_UNSPECIFIED: CommandState
COMMAND_STATE_PENDING: CommandState
COMMAND_STATE_SUCCEEDED: CommandState
COMMAND_STATE_FAILED: CommandState

class GetCommandStatusRequest(_message.Message):
    __slots__ = ("command_id_prefix", "state", "limit")
    COMMAND_ID_PREFIX_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    command_id_prefix: str
    state: CommandState
    limit: int
    def __init__(self, command_id_prefix: _Optional[str] = ..., state: _Optional[_Union[CommandState, str]] = ..., limit: _Optional[int] = ...) -> None: ...

class GetCommandStatusResponse(_message.Message):
    __slots__ = ("command_status",)
    COMMAND_STATUS_FIELD_NUMBER: _ClassVar[int]
    command_status: _containers.RepeatedCompositeFieldContainer[CommandStatus]
    def __init__(self, command_status: _Optional[_Iterable[_Union[CommandStatus, _Mapping]]] = ...) -> None: ...

class CommandStatus(_message.Message):
    __slots__ = ("started", "completed", "completion", "state", "commands", "request_statistics", "updates")
    STARTED_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    REQUEST_STATISTICS_FIELD_NUMBER: _ClassVar[int]
    UPDATES_FIELD_NUMBER: _ClassVar[int]
    started: _timestamp_pb2.Timestamp
    completed: _timestamp_pb2.Timestamp
    completion: _completion_pb2.Completion
    state: CommandState
    commands: _containers.RepeatedCompositeFieldContainer[_commands_pb2.Command]
    request_statistics: RequestStatistics
    updates: CommandUpdates
    def __init__(self, started: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completion: _Optional[_Union[_completion_pb2.Completion, _Mapping]] = ..., state: _Optional[_Union[CommandState, str]] = ..., commands: _Optional[_Iterable[_Union[_commands_pb2.Command, _Mapping]]] = ..., request_statistics: _Optional[_Union[RequestStatistics, _Mapping]] = ..., updates: _Optional[_Union[CommandUpdates, _Mapping]] = ...) -> None: ...

class RequestStatistics(_message.Message):
    __slots__ = ("envelopes", "request_size", "recipients")
    ENVELOPES_FIELD_NUMBER: _ClassVar[int]
    REQUEST_SIZE_FIELD_NUMBER: _ClassVar[int]
    RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    envelopes: int
    request_size: int
    recipients: int
    def __init__(self, envelopes: _Optional[int] = ..., request_size: _Optional[int] = ..., recipients: _Optional[int] = ...) -> None: ...

class CommandUpdates(_message.Message):
    __slots__ = ("created", "archived", "exercised", "fetched", "looked_up_by_key")
    CREATED_FIELD_NUMBER: _ClassVar[int]
    ARCHIVED_FIELD_NUMBER: _ClassVar[int]
    EXERCISED_FIELD_NUMBER: _ClassVar[int]
    FETCHED_FIELD_NUMBER: _ClassVar[int]
    LOOKED_UP_BY_KEY_FIELD_NUMBER: _ClassVar[int]
    created: _containers.RepeatedCompositeFieldContainer[Contract]
    archived: _containers.RepeatedCompositeFieldContainer[Contract]
    exercised: int
    fetched: int
    looked_up_by_key: int
    def __init__(self, created: _Optional[_Iterable[_Union[Contract, _Mapping]]] = ..., archived: _Optional[_Iterable[_Union[Contract, _Mapping]]] = ..., exercised: _Optional[int] = ..., fetched: _Optional[int] = ..., looked_up_by_key: _Optional[int] = ...) -> None: ...

class Contract(_message.Message):
    __slots__ = ("template_id", "contract_id", "contract_key")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_KEY_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    contract_id: str
    contract_key: _value_pb2.Value
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., contract_id: _Optional[str] = ..., contract_key: _Optional[_Union[_value_pb2.Value, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/admin/identity_provider_config_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/admin/identity_provider_config_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/daml/ledger/api/v1/admin/identity_provider_config_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\x1a google/protobuf/field_mask.proto\"\xc0\x01\n\x16IdentityProviderConfig\x12\x30\n\x14identity_provider_id\x18\x01 \x01(\tR\x12identityProviderId\x12%\n\x0eis_deactivated\x18\x02 \x01(\x08R\risDeactivated\x12\x16\n\x06issuer\x18\x03 \x01(\tR\x06issuer\x12\x19\n\x08jwks_url\x18\x04 \x01(\tR\x07jwksUrl\x12\x1a\n\x08\x61udience\x18\x05 \x01(\tR\x08\x61udience\"\x95\x01\n#CreateIdentityProviderConfigRequest\x12n\n\x18identity_provider_config\x18\x01 \x01(\x0b\x32\x34.com.daml.ledger.api.v1.admin.IdentityProviderConfigR\x16identityProviderConfig\"\x96\x01\n$CreateIdentityProviderConfigResponse\x12n\n\x18identity_provider_config\x18\x01 \x01(\x0b\x32\x34.com.daml.ledger.api.v1.admin.IdentityProviderConfigR\x16identityProviderConfig\"T\n GetIdentityProviderConfigRequest\x12\x30\n\x14identity_provider_id\x18\x01 \x01(\tR\x12identityProviderId\"\x93\x01\n!GetIdentityProviderConfigResponse\x12n\n\x18identity_provider_config\x18\x01 \x01(\x0b\x32\x34.com.daml.ledger.api.v1.admin.IdentityProviderConfigR\x16identityProviderConfig\"$\n\"ListIdentityProviderConfigsRequest\"\x97\x01\n#ListIdentityProviderConfigsResponse\x12p\n\x19identity_provider_configs\x18\x01 \x03(\x0b\x32\x34.com.daml.ledger.api.v1.admin.IdentityProviderConfigR\x17identityProviderConfigs\"\xd2\x01\n#UpdateIdentityProviderConfigRequest\x12n\n\x18identity_provider_config\x18\x01 \x01(\x0b\x32\x34.com.daml.ledger.api.v1.admin.IdentityProviderConfigR\x16identityProviderConfig\x12;\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x96\x01\n$UpdateIdentityProviderConfigResponse\x12n\n\x18identity_provider_config\x18\x01 \x01(\x0b\x32\x34.com.daml.ledger.api.v1.admin.IdentityProviderConfigR\x16identityProviderConfig\"W\n#DeleteIdentityProviderConfigRequest\x12\x30\n\x14identity_provider_id\x18\x01 \x01(\tR\x12identityProviderId\"&\n$DeleteIdentityProviderConfigResponse2\xdb\x06\n\x1dIdentityProviderConfigService\x12\xa5\x01\n\x1c\x43reateIdentityProviderConfig\x12\x41.com.daml.ledger.api.v1.admin.CreateIdentityProviderConfigRequest\x1a\x42.com.daml.ledger.api.v1.admin.CreateIdentityProviderConfigResponse\x12\x9c\x01\n\x19GetIdentityProviderConfig\x12>.com.daml.ledger.api.v1.admin.GetIdentityProviderConfigRequest\x1a?.com.daml.ledger.api.v1.admin.GetIdentityProviderConfigResponse\x12\xa5\x01\n\x1cUpdateIdentityProviderConfig\x12\x41.com.daml.ledger.api.v1.admin.UpdateIdentityProviderConfigRequest\x1a\x42.com.daml.ledger.api.v1.admin.UpdateIdentityProviderConfigResponse\x12\xa2\x01\n\x1bListIdentityProviderConfigs\x12@.com.daml.ledger.api.v1.admin.ListIdentityProviderConfigsRequest\x1a\x41.com.daml.ledger.api.v1.admin.ListIdentityProviderConfigsResponse\x12\xa5\x01\n\x1c\x44\x65leteIdentityProviderConfig\x12\x41.com.daml.ledger.api.v1.admin.DeleteIdentityProviderConfigRequest\x1a\x42.com.daml.ledger.api.v1.admin.DeleteIdentityProviderConfigResponseB\xb3\x01\n\x1c\x63om.daml.ledger.api.v1.adminB\'IdentityProviderConfigServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.admin.identity_provider_config_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v1.adminB\'IdentityProviderConfigServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\252\002\034Com.Daml.Ledger.Api.V1.Admin'
  _globals['_IDENTITYPROVIDERCONFIG']._serialized_start=136
  _globals['_IDENTITYPROVIDERCONFIG']._serialized_end=328
  _globals['_CREATEIDENTITYPROVIDERCONFIGREQUEST']._serialized_start=331
  _globals['_CREATEIDENTITYPROVIDERCONFIGREQUEST']._serialized_end=480
  _globals['_CREATEIDENTITYPROVIDERCONFIGRESPONSE']._serialized_start=483
  _globals['_CREATEIDENTITYPROVIDERCONFIGRESPONSE']._serialized_end=633
  _globals['_GETIDENTITYPROVIDERCONFIGREQUEST']._serialized_start=635
  _globals['_GETIDENTITYPROVIDERCONFIGREQUEST']._serialized_end=719
  _globals['_GETIDENTITYPROVIDERCONFIGRESPONSE']._serialized_start=722
  _globals['_GETIDENTITYPROVIDERCONFIGRESPONSE']._serialized_end=869
  _globals['_LISTIDENTITYPROVIDERCONFIGSREQUEST']._serialized_start=871
  _globals['_LISTIDENTITYPROVIDERCONFIGSREQUEST']._serialized_end=907
  _globals['_LISTIDENTITYPROVIDERCONFIGSRESPONSE']._serialized_start=910
  _globals['_LISTIDENTITYPROVIDERCONFIGSRESPONSE']._serialized_end=1061
  _globals['_UPDATEIDENTITYPROVIDERCONFIGREQUEST']._serialized_start=1064
  _globals['_UPDATEIDENTITYPROVIDERCONFIGREQUEST']._serialized_end=1274
  _globals['_UPDATEIDENTITYPROVIDERCONFIGRESPONSE']._serialized_start=1277
  _globals['_UPDATEIDENTITYPROVIDERCONFIGRESPONSE']._serialized_end=1427
  _globals['_DELETEIDENTITYPROVIDERCONFIGREQUEST']._serialized_start=1429
  _globals['_DELETEIDENTITYPROVIDERCONFIGREQUEST']._serialized_end=1516
  _globals['_DELETEIDENTITYPROVIDERCONFIGRESPONSE']._serialized_start=1518
  _globals['_DELETEIDENTITYPROVIDERCONFIGRESPONSE']._serialized_end=1556
  _globals['_IDENTITYPROVIDERCONFIGSERVICE']._serialized_start=1559
  _globals['_IDENTITYPROVIDERCONFIGSERVICE']._serialized_end=2418
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/traffic_control_parameters.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/traffic_control_parameters.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEcom/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x12$com.digitalasset.canton.protocol.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xaa\x03\n\x18TrafficControlParameters\x12\x35\n\x17max_base_traffic_amount\x18\x01 \x01(\x04R\x14maxBaseTrafficAmount\x12m\n&max_base_traffic_accumulation_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\"maxBaseTrafficAccumulationDuration\x12>\n\x1cread_vs_write_scaling_factor\x18\x04 \x01(\rR\x18readVsWriteScalingFactor\x12t\n*set_balance_request_submission_window_size\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR%setBalanceRequestSubmissionWindowSize\x12\x32\n\x15\x65nforce_rate_limiting\x18\x06 \x01(\x08R\x13\x65nforceRateLimiting\"\xa1\x01\n\x0eTrafficReceipt\x12#\n\rconsumed_cost\x18\x01 \x01(\x04R\x0c\x63onsumedCost\x12\x34\n\x16\x65xtra_traffic_consumed\x18\x02 \x01(\x04R\x14\x65xtraTrafficConsumed\x12\x34\n\x16\x62\x61se_traffic_remainder\x18\x03 \x01(\x04R\x14\x62\x61seTrafficRemainder\"\xf6\x01\n\x0fTrafficConsumed\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x34\n\x16\x65xtra_traffic_consumed\x18\x02 \x01(\x04R\x14\x65xtraTrafficConsumed\x12\x34\n\x16\x62\x61se_traffic_remainder\x18\x03 \x01(\x04R\x14\x62\x61seTrafficRemainder\x12,\n\x12last_consumed_cost\x18\x04 \x01(\x04R\x10lastConsumedCost\x12\x31\n\x14sequencing_timestamp\x18\x05 \x01(\x03R\x13sequencingTimestamp\"\xad\x01\n\x10TrafficPurchased\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12\x36\n\x17\x65xtra_traffic_purchased\x18\x03 \x01(\x04R\x15\x65xtraTrafficPurchased\x12\x31\n\x14sequencing_timestamp\x18\x04 \x01(\x03R\x13sequencingTimestamp\"\xb4\x02\n\x0cTrafficState\x12\x36\n\x17\x65xtra_traffic_purchased\x18\x01 \x01(\x03R\x15\x65xtraTrafficPurchased\x12\x34\n\x16\x65xtra_traffic_consumed\x18\x02 \x01(\x03R\x14\x65xtraTrafficConsumed\x12\x34\n\x16\x62\x61se_traffic_remainder\x18\x03 \x01(\x03R\x14\x62\x61seTrafficRemainder\x12,\n\x12last_consumed_cost\x18\x04 \x01(\x04R\x10lastConsumedCost\x12\x1c\n\ttimestamp\x18\x05 \x01(\x03R\ttimestamp\x12\x34\n\x06serial\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x06serial\"\xa1\x01\n\x1aSetTrafficPurchasedMessage\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12\x36\n\x17total_traffic_purchased\x18\x04 \x01(\x04R\x15totalTrafficPurchased\x12\x1b\n\tdomain_id\x18\x05 \x01(\tR\x08\x64omainIdBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.traffic_control_parameters_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_TRAFFICCONTROLPARAMETERS']._serialized_start=176
  _globals['_TRAFFICCONTROLPARAMETERS']._serialized_end=602
  _globals['_TRAFFICRECEIPT']._serialized_start=605
  _globals['_TRAFFICRECEIPT']._serialized_end=766
  _globals['_TRAFFICCONSUMED']._serialized_start=769
  _globals['_TRAFFICCONSUMED']._serialized_end=1015
  _globals['_TRAFFICPURCHASED']._serialized_start=1018
  _globals['_TRAFFICPURCHASED']._serialized_end=1191
  _globals['_TRAFFICSTATE']._serialized_start=1194
  _globals['_TRAFFICSTATE']._serialized_end=1502
  _globals['_SETTRAFFICPURCHASEDMESSAGE']._serialized_start=1505
  _globals['_SETTRAFFICPURCHASEDMESSAGE']._serialized_end=1666
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .untyped_versioned_message_pb2 import UntypedVersionedMessage

__all__ = [
    "UntypedVersionedMessage",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v30 import crypto_pb2 as _crypto_pb2
from . import common_stable_pb2 as _common_stable_pb2
from . import traffic_control_parameters_pb2 as _traffic_control_parameters_pb2
from ...v30 import trace_context_pb2 as _trace_context_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.rpc import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PossiblyIgnoredSequencedEvent(_message.Message):
    __slots__ = ("counter", "timestamp", "trace_context", "is_ignored", "underlying")
    COUNTER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    IS_IGNORED_FIELD_NUMBER: _ClassVar[int]
    UNDERLYING_FIELD_NUMBER: _ClassVar[int]
    counter: int
    timestamp: int
    trace_context: _trace_context_pb2.TraceContext
    is_ignored: bool
    underlying: _wrappers_pb2.BytesValue
    def __init__(self, counter: _Optional[int] = ..., timestamp: _Optional[int] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ..., is_ignored: bool = ..., underlying: _Optional[_Union[_wrappers_pb2.BytesValue, _Mapping]] = ...) -> None: ...

class RecipientsTree(_message.Message):
    __slots__ = ("recipients", "children")
    RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    recipients: _containers.RepeatedScalarFieldContainer[str]
    children: _containers.RepeatedCompositeFieldContainer[RecipientsTree]
    def __init__(self, recipients: _Optional[_Iterable[str]] = ..., children: _Optional[_Iterable[_Union[RecipientsTree, _Mapping]]] = ...) -> None: ...

class Recipients(_message.Message):
    __slots__ = ("recipients_tree",)
    RECIPIENTS_TREE_FIELD_NUMBER: _ClassVar[int]
    recipients_tree: _containers.RepeatedCompositeFieldContainer[RecipientsTree]
    def __init__(self, recipients_tree: _Optional[_Iterable[_Union[RecipientsTree, _Mapping]]] = ...) -> None: ...

class ServiceAgreement(_message.Message):
    __slots__ = ("id", "legal_text")
    ID_FIELD_NUMBER: _ClassVar[int]
    LEGAL_TEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    legal_text: str
    def __init__(self, id: _Optional[str] = ..., legal_text: _Optional[str] = ...) -> None: ...

class Handshake(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("client_protocol_versions", "minimum_protocol_version")
        CLIENT_PROTOCOL_VERSIONS_FIELD_NUMBER: _ClassVar[int]
        MINIMUM_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
        client_protocol_versions: _containers.RepeatedScalarFieldContainer[str]
        minimum_protocol_version: _wrappers_pb2.StringValue
        def __init__(self, client_protocol_versions: _Optional[_Iterable[str]] = ..., minimum_protocol_version: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("server_protocol_version", "success", "failure")
        SERVER_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
        SUCCESS_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        server_protocol_version: str
        success: Handshake.Success
        failure: Handshake.Failure
        def __init__(self, server_protocol_version: _Optional[str] = ..., success: _Optional[_Union[Handshake.Success, _Mapping]] = ..., failure: _Optional[_Union[Handshake.Failure, _Mapping]] = ...) -> None: ...
    class Success(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Failure(_message.Message):
        __slots__ = ("reason",)
        REASON_FIELD_NUMBER: _ClassVar[int]
        reason: str
        def __init__(self, reason: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class SequencingSubmissionCost(_message.Message):
    __slots__ = ("cost",)
    COST_FIELD_NUMBER: _ClassVar[int]
    cost: int
    def __init__(self, cost: _Optional[int] = ...) -> None: ...

class SinglePartySignatures(_message.Message):
    __slots__ = ("party", "signatures")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    party: str
    signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
    def __init__(self, party: _Optional[str] = ..., signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ...) -> None: ...

class PartySignatures(_message.Message):
    __slots__ = ("signatures",)
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    signatures: _containers.RepeatedCompositeFieldContainer[SinglePartySignatures]
    def __init__(self, signatures: _Optional[_Iterable[_Union[SinglePartySignatures, _Mapping]]] = ...) -> None: ...

class StaticDomainParameters(_message.Message):
    __slots__ = ("required_signing_key_schemes", "required_encryption_specs", "required_symmetric_key_schemes", "required_hash_algorithms", "required_crypto_key_formats", "protocol_version")
    REQUIRED_SIGNING_KEY_SCHEMES_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_ENCRYPTION_SPECS_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_SYMMETRIC_KEY_SCHEMES_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_HASH_ALGORITHMS_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_CRYPTO_KEY_FORMATS_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    required_signing_key_schemes: _containers.RepeatedScalarFieldContainer[_crypto_pb2.SigningKeyScheme]
    required_encryption_specs: _crypto_pb2.RequiredEncryptionSpecs
    required_symmetric_key_schemes: _containers.RepeatedScalarFieldContainer[_crypto_pb2.SymmetricKeyScheme]
    required_hash_algorithms: _containers.RepeatedScalarFieldContainer[_crypto_pb2.HashAlgorithm]
    required_crypto_key_formats: _containers.RepeatedScalarFieldContainer[_crypto_pb2.CryptoKeyFormat]
    protocol_version: int
    def __init__(self, required_signing_key_schemes: _Optional[_Iterable[_Union[_crypto_pb2.SigningKeyScheme, str]]] = ..., required_encryption_specs: _Optional[_Union[_crypto_pb2.RequiredEncryptionSpecs, _Mapping]] = ..., required_symmetric_key_schemes: _Optional[_Iterable[_Union[_crypto_pb2.SymmetricKeyScheme, str]]] = ..., required_hash_algorithms: _Optional[_Iterable[_Union[_crypto_pb2.HashAlgorithm, str]]] = ..., required_crypto_key_formats: _Optional[_Iterable[_Union[_crypto_pb2.CryptoKeyFormat, str]]] = ..., protocol_version: _Optional[int] = ...) -> None: ...

class Envelope(_message.Message):
    __slots__ = ("content", "recipients", "signatures")
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    content: bytes
    recipients: Recipients
    signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
    def __init__(self, content: _Optional[bytes] = ..., recipients: _Optional[_Union[Recipients, _Mapping]] = ..., signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ...) -> None: ...

class Batch(_message.Message):
    __slots__ = ("envelopes",)
    ENVELOPES_FIELD_NUMBER: _ClassVar[int]
    envelopes: _containers.RepeatedCompositeFieldContainer[Envelope]
    def __init__(self, envelopes: _Optional[_Iterable[_Union[Envelope, _Mapping]]] = ...) -> None: ...

class CompressedBatch(_message.Message):
    __slots__ = ("algorithm", "compressed_batch")
    class CompressionAlgorithm(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        COMPRESSION_ALGORITHM_UNSPECIFIED: _ClassVar[CompressedBatch.CompressionAlgorithm]
        COMPRESSION_ALGORITHM_GZIP: _ClassVar[CompressedBatch.CompressionAlgorithm]
    COMPRESSION_ALGORITHM_UNSPECIFIED: CompressedBatch.CompressionAlgorithm
    COMPRESSION_ALGORITHM_GZIP: CompressedBatch.CompressionAlgorithm
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    COMPRESSED_BATCH_FIELD_NUMBER: _ClassVar[int]
    algorithm: CompressedBatch.CompressionAlgorithm
    compressed_batch: bytes
    def __init__(self, algorithm: _Optional[_Union[CompressedBatch.CompressionAlgorithm, str]] = ..., compressed_batch: _Optional[bytes] = ...) -> None: ...

class SequencedEvent(_message.Message):
    __slots__ = ("counter", "timestamp", "domain_id", "message_id", "batch", "deliver_error_reason", "topology_timestamp", "traffic_receipt")
    COUNTER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    BATCH_FIELD_NUMBER: _ClassVar[int]
    DELIVER_ERROR_REASON_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TRAFFIC_RECEIPT_FIELD_NUMBER: _ClassVar[int]
    counter: int
    timestamp: int
    domain_id: str
    message_id: _wrappers_pb2.StringValue
    batch: CompressedBatch
    deliver_error_reason: _status_pb2.Status
    topology_timestamp: _wrappers_pb2.Int64Value
    traffic_receipt: _traffic_control_parameters_pb2.TrafficReceipt
    def __init__(self, counter: _Optional[int] = ..., timestamp: _Optional[int] = ..., domain_id: _Optional[str] = ..., message_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., batch: _Optional[_Union[CompressedBatch, _Mapping]] = ..., deliver_error_reason: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., topology_timestamp: _Optional[_Union[_wrappers_pb2.Int64Value, _Mapping]] = ..., traffic_receipt: _Optional[_Union[_traffic_control_parameters_pb2.TrafficReceipt, _Mapping]] = ...) -> None: ...

class SubmissionRequest(_message.Message):
    __slots__ = ("sender", "message_id", "batch", "max_sequencing_time", "topology_timestamp", "aggregation_rule", "submission_cost")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    BATCH_FIELD_NUMBER: _ClassVar[int]
    MAX_SEQUENCING_TIME_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    AGGREGATION_RULE_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_COST_FIELD_NUMBER: _ClassVar[int]
    sender: str
    message_id: str
    batch: CompressedBatch
    max_sequencing_time: int
    topology_timestamp: _wrappers_pb2.Int64Value
    aggregation_rule: _common_stable_pb2.AggregationRule
    submission_cost: SequencingSubmissionCost
    def __init__(self, sender: _Optional[str] = ..., message_id: _Optional[str] = ..., batch: _Optional[_Union[CompressedBatch, _Mapping]] = ..., max_sequencing_time: _Optional[int] = ..., topology_timestamp: _Optional[_Union[_wrappers_pb2.Int64Value, _Mapping]] = ..., aggregation_rule: _Optional[_Union[_common_stable_pb2.AggregationRule, _Mapping]] = ..., submission_cost: _Optional[_Union[SequencingSubmissionCost, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CatchUpConfig(_message.Message):
    __slots__ = ("catchup_interval_skip", "nr_intervals_to_trigger_catchup")
    CATCHUP_INTERVAL_SKIP_FIELD_NUMBER: _ClassVar[int]
    NR_INTERVALS_TO_TRIGGER_CATCHUP_FIELD_NUMBER: _ClassVar[int]
    catchup_interval_skip: int
    nr_intervals_to_trigger_catchup: int
    def __init__(self, catchup_interval_skip: _Optional[int] = ..., nr_intervals_to_trigger_catchup: _Optional[int] = ...) -> None: ...

class DynamicDomainParameters(_message.Message):
    __slots__ = ("participant_response_timeout", "mediator_reaction_timeout", "transfer_exclusivity_timeout", "topology_change_delay", "ledger_time_record_time_tolerance", "reconciliation_interval", "mediator_deduplication_timeout", "max_rate_per_participant", "max_request_size", "catch_up_parameters")
    PARTICIPANT_RESPONSE_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_REACTION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_EXCLUSIVITY_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_CHANGE_DELAY_FIELD_NUMBER: _ClassVar[int]
    LEDGER_TIME_RECORD_TIME_TOLERANCE_FIELD_NUMBER: _ClassVar[int]
    RECONCILIATION_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_DEDUPLICATION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    MAX_RATE_PER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    MAX_REQUEST_SIZE_FIELD_NUMBER: _ClassVar[int]
    CATCH_UP_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    participant_response_timeout: _duration_pb2.Duration
    mediator_reaction_timeout: _duration_pb2.Duration
    transfer_exclusivity_timeout: _duration_pb2.Duration
    topology_change_delay: _duration_pb2.Duration
    ledger_time_record_time_tolerance: _duration_pb2.Duration
    reconciliation_interval: _duration_pb2.Duration
    mediator_deduplication_timeout: _duration_pb2.Duration
    max_rate_per_participant: int
    max_request_size: int
    catch_up_parameters: CatchUpConfig
    def __init__(self, participant_response_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., mediator_reaction_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., transfer_exclusivity_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., topology_change_delay: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., ledger_time_record_time_tolerance: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., reconciliation_interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., mediator_deduplication_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_rate_per_participant: _Optional[int] = ..., max_request_size: _Optional[int] = ..., catch_up_parameters: _Optional[_Union[CatchUpConfig, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v1/mediator.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v1/mediator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..v0 import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_common__pb2
from ..v0 import mediator_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_mediator__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_merkle__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2com/digitalasset/canton/protocol/v1/mediator.proto\x12#com.digitalasset.canton.protocol.v1\x1a\x30\x63om/digitalasset/canton/protocol/v0/common.proto\x1a\x32\x63om/digitalasset/canton/protocol/v0/mediator.proto\x1a\x30\x63om/digitalasset/canton/protocol/v1/merkle.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfd\x01\n\x18TransactionResultMessage\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12\x46\n\x07verdict\x18\x02 \x01(\x0b\x32,.com.digitalasset.canton.protocol.v1.VerdictR\x07verdict\x12^\n\x11notification_tree\x18\x05 \x01(\x0b\x32\x31.com.digitalasset.canton.protocol.v1.InformeeTreeR\x10notificationTree\"\x9c\x02\n\x07Verdict\x12\x32\n\x07\x61pprove\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07\x61pprove\x12g\n\x12participant_reject\x18\x02 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v1.ParticipantRejectH\x00R\x11participantReject\x12^\n\x0fmediator_reject\x18\x03 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v1.MediatorRejectH\x00R\x0emediatorRejectB\x0e\n\x0csome_verdictJ\x04\x08\x04\x10\x05\"[\n\x0cInformeeTree\x12K\n\x04tree\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v1.GenTransactionTreeR\x04tree\"c\n\x11ParticipantReject\x12N\n\x07reasons\x18\x01 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v0.RejectionReasonR\x07reasons\"r\n\x0eMediatorReject\x12\x14\n\x05\x63\x61use\x18\x02 \x01(\tR\x05\x63\x61use\x12\x1d\n\nerror_code\x18\x03 \x01(\tR\terrorCode\x12%\n\x0e\x65rror_category\x18\x04 \x01(\rR\rerrorCategoryJ\x04\x08\x01\x10\x02\"\x97\x02\n\x1eMalformedMediatorRequestResult\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12J\n\tview_type\x18\x03 \x01(\x0e\x32-.com.digitalasset.canton.protocol.v0.ViewTypeR\x08viewType\x12Q\n\trejection\x18\x04 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v1.MediatorRejectR\trejection\"\x89\x02\n\x0eTransferResult\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12%\n\rorigin_domain\x18\x02 \x01(\tH\x00R\x0coriginDomain\x12%\n\rtarget_domain\x18\x03 \x01(\tH\x00R\x0ctargetDomain\x12\x1c\n\tinformees\x18\x04 \x03(\tR\tinformees\x12\x46\n\x07verdict\x18\x05 \x01(\x0b\x32,.com.digitalasset.canton.protocol.v1.VerdictR\x07verdictB\x08\n\x06\x64omainBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v1.mediator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1'
  _globals['_TRANSACTIONRESULTMESSAGE']._serialized_start=306
  _globals['_TRANSACTIONRESULTMESSAGE']._serialized_end=559
  _globals['_VERDICT']._serialized_start=562
  _globals['_VERDICT']._serialized_end=846
  _globals['_INFORMEETREE']._serialized_start=848
  _globals['_INFORMEETREE']._serialized_end=939
  _globals['_PARTICIPANTREJECT']._serialized_start=941
  _globals['_PARTICIPANTREJECT']._serialized_end=1040
  _globals['_MEDIATORREJECT']._serialized_start=1042
  _globals['_MEDIATORREJECT']._serialized_end=1156
  _globals['_MALFORMEDMEDIATORREQUESTRESULT']._serialized_start=1159
  _globals['_MALFORMEDMEDIATORREQUESTRESULT']._serialized_end=1438
  _globals['_TRANSFERRESULT']._serialized_start=1441
  _globals['_TRANSFERRESULT']._serialized_end=1706
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/participant_transaction.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/participant_transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_merkle__pb2
from . import quorum_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_quorum__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBcom/digitalasset/canton/protocol/v30/participant_transaction.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/common.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/merkle.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/quorum.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\"r\n\x13\x44\x65\x64uplicationPeriod\x12\x37\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x08\x64uration\x12\x18\n\x06offset\x18\x02 \x01(\x0cH\x00R\x06offsetB\x08\n\x06period\"\xbe\x01\n\x13ParticipantMetadata\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x1f\n\x0bledger_time\x18\x02 \x01(\x03R\nledgerTime\x12\'\n\x0fsubmission_time\x18\x03 \x01(\x03R\x0esubmissionTime\x12\x1f\n\x0bworkflow_id\x18\x04 \x01(\tR\nworkflowId\"\xec\x01\n\x0fRootHashMessage\x12\x1b\n\troot_hash\x18\x01 \x01(\x0cR\x08rootHash\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12K\n\tview_type\x18\x03 \x01(\x0e\x32..com.digitalasset.canton.protocol.v30.ViewTypeR\x08viewType\x12\x38\n\x18submission_topology_time\x18\x04 \x01(\x03R\x16submissionTopologyTime\x12\x18\n\x07payload\x18\x05 \x01(\x0cR\x07payload\"\x9f\x02\n\x08ViewNode\x12]\n\x10view_common_data\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.BlindableNodeR\x0eviewCommonData\x12g\n\x15view_participant_data\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.BlindableNodeR\x13viewParticipantData\x12K\n\x08subviews\x18\x03 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v30.MerkleSeqR\x08subviews\"\xb4\x01\n\x0eViewCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x1c\n\tinformees\x18\x02 \x03(\tR\tinformees\x12\x46\n\x07quorums\x18\x03 \x03(\x0b\x32,.com.digitalasset.canton.protocol.v30.QuorumR\x07quorums\"8\n\x08Informee\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x16\n\x06weight\x18\x02 \x01(\x05R\x06weight\"_\n\x1bParticipantRandomnessLookup\x12\x1e\n\nrandomness\x18\x01 \x01(\x0cR\nrandomness\x12 \n\x0b\x66ingerprint\x18\x02 \x01(\tR\x0b\x66ingerprint\"\x1c\n\x16ViewParticipantMessage:\x02\x18\x01\"\xf0\x01\n\x0fInformeeMessage\x12\x64\n\x12\x66ull_informee_tree\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v30.FullInformeeTreeR\x10\x66ullInformeeTree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\x8f\x01\n\x18LightTransactionViewTree\x12L\n\x04tree\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.GenTransactionTreeR\x04tree\x12%\n\x0esubview_hashes\x18\x02 \x03(\x0cR\rsubviewHashes\"`\n\x10\x46ullInformeeTree\x12L\n\x04tree\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.GenTransactionTreeR\x04tree\"\xb4\x01\n\x0f\x43reatedContract\x12V\n\x08\x63ontract\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SerializableContractR\x08\x63ontract\x12(\n\x10\x63onsumed_in_core\x18\x02 \x01(\x08R\x0e\x63onsumedInCore\x12\x1f\n\x0brolled_back\x18\x03 \x01(\x08R\nrolledBack\"\x83\x01\n\rInputContract\x12V\n\x08\x63ontract\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SerializableContractR\x08\x63ontract\x12\x1a\n\x08\x63onsumed\x18\x02 \x01(\x08R\x08\x63onsumed\"\xac\x01\n\x0e\x43ommonMetadata\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12%\n\x0emediator_group\x18\x05 \x01(\x05R\rmediatorGroupJ\x04\x08\x02\x10\x03\"\x9f\x03\n\x11SubmitterMetadata\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x15\n\x06\x61\x63t_as\x18\x02 \x03(\tR\x05\x61\x63tAs\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x04 \x01(\tR\tcommandId\x12<\n\x1asubmitting_participant_uid\x18\x05 \x01(\tR\x18submittingParticipantUid\x12#\n\rsubmission_id\x18\x06 \x01(\tR\x0csubmissionId\x12\\\n\x0c\x64\x65\x64up_period\x18\x07 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.DeduplicationPeriodR\x0b\x64\x65\x64upPeriod\x12.\n\x13max_sequencing_time\x18\x08 \x01(\x03R\x11maxSequencingTime\"\xe3\x01\n\x10SessionKeyLookup\x12\x34\n\x16session_key_randomness\x18\x01 \x01(\x0cR\x14sessionKeyRandomness\x12w\n\x19\x65ncryption_algorithm_spec\x18\x02 \x01(\x0e\x32;.com.digitalasset.canton.crypto.v30.EncryptionAlgorithmSpecR\x17\x65ncryptionAlgorithmSpec\x12 \n\x0b\x66ingerprint\x18\x03 \x01(\tR\x0b\x66ingerprint\"\xa6\x04\n\x14\x45ncryptedViewMessage\x12\x1b\n\tview_tree\x18\x01 \x01(\x0cR\x08viewTree\x12\x63\n\x11\x65ncryption_scheme\x18\x02 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x10\x65ncryptionScheme\x12w\n submitting_participant_signature\x18\x03 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\x12\x1b\n\tview_hash\x18\x04 \x01(\x0cR\x08viewHash\x12\x1e\n\nrandomness\x18\x05 \x01(\x0cR\nrandomness\x12l\n\x16session_key_randomness\x18\x06 \x03(\x0b\x32\x36.com.digitalasset.canton.protocol.v30.SessionKeyLookupR\x14sessionKeyRandomness\x12\x1b\n\tdomain_id\x18\x07 \x01(\tR\x08\x64omainId\x12K\n\tview_type\x18\x08 \x01(\x0e\x32..com.digitalasset.canton.protocol.v30.ViewTypeR\x08viewType\"\xaf\t\n\x11\x41\x63tionDescription\x12i\n\x06\x63reate\x18\x01 \x01(\x0b\x32O.com.digitalasset.canton.protocol.v30.ActionDescription.CreateActionDescriptionH\x00R\x06\x63reate\x12o\n\x08\x65xercise\x18\x02 \x01(\x0b\x32Q.com.digitalasset.canton.protocol.v30.ActionDescription.ExerciseActionDescriptionH\x00R\x08\x65xercise\x12\x66\n\x05\x66\x65tch\x18\x03 \x01(\x0b\x32N.com.digitalasset.canton.protocol.v30.ActionDescription.FetchActionDescriptionH\x00R\x05\x66\x65tch\x12z\n\rlookup_by_key\x18\x04 \x01(\x0b\x32T.com.digitalasset.canton.protocol.v30.ActionDescription.LookupByKeyActionDescriptionH\x00R\x0blookupByKey\x1aW\n\x17\x43reateActionDescription\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12\x1b\n\tnode_seed\x18\x02 \x01(\x0cR\x08nodeSeed\x1a\xf7\x02\n\x19\x45xerciseActionDescription\x12*\n\x11input_contract_id\x18\x01 \x01(\tR\x0finputContractId\x12\x16\n\x06\x63hoice\x18\x02 \x01(\tR\x06\x63hoice\x12!\n\x0c\x63hosen_value\x18\x03 \x01(\x0cR\x0b\x63hosenValue\x12\x16\n\x06\x61\x63tors\x18\x04 \x03(\tR\x06\x61\x63tors\x12\x15\n\x06\x62y_key\x18\x05 \x01(\x08R\x05\x62yKey\x12\x1b\n\tnode_seed\x18\x06 \x01(\x0cR\x08nodeSeed\x12\x16\n\x06\x66\x61iled\x18\x08 \x01(\x08R\x06\x66\x61iled\x12?\n\x0cinterface_id\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0binterfaceId\x12\x1f\n\x0btemplate_id\x18\n \x01(\tR\ntemplateId\x12-\n\x12package_preference\x18\x0b \x03(\tR\x11packagePreference\x1a\x94\x01\n\x16\x46\x65tchActionDescription\x12*\n\x11input_contract_id\x18\x01 \x01(\tR\x0finputContractId\x12\x16\n\x06\x61\x63tors\x18\x02 \x03(\tR\x06\x61\x63tors\x12\x15\n\x06\x62y_key\x18\x03 \x01(\x08R\x05\x62yKey\x12\x1f\n\x0btemplate_id\x18\x04 \x01(\tR\ntemplateId\x1a\x61\n\x1cLookupByKeyActionDescription\x12\x41\n\x03key\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v30.GlobalKeyR\x03keyB\r\n\x0b\x64\x65scription\"\xfd\x07\n\x13ViewParticipantData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12T\n\x0b\x63ore_inputs\x18\x02 \x03(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.InputContractR\ncoreInputs\x12X\n\x0c\x63reated_core\x18\x03 \x03(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CreatedContractR\x0b\x63reatedCore\x12K\n#created_in_subview_archived_in_core\x18\x04 \x03(\tR\x1e\x63reatedInSubviewArchivedInCore\x12j\n\rresolved_keys\x18\x05 \x03(\x0b\x32\x45.com.digitalasset.canton.protocol.v30.ViewParticipantData.ResolvedKeyR\x0cresolvedKeys\x12\x66\n\x12\x61\x63tion_description\x18\x06 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.ActionDescriptionR\x11\x61\x63tionDescription\x12t\n\x10rollback_context\x18\x07 \x01(\x0b\x32I.com.digitalasset.canton.protocol.v30.ViewParticipantData.RollbackContextR\x0frollbackContext\x1a+\n\x07\x46reeKey\x12 \n\x0bmaintainers\x18\x01 \x03(\tR\x0bmaintainers\x1a\xda\x01\n\x0bResolvedKey\x12\x41\n\x03key\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v30.GlobalKeyR\x03key\x12!\n\x0b\x63ontract_id\x18\x02 \x01(\tH\x00R\ncontractId\x12W\n\x04\x66ree\x18\x03 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.ViewParticipantData.FreeKeyH\x00R\x04\x66reeB\x0c\n\nresolution\x1aW\n\x0fRollbackContext\x12%\n\x0erollback_scope\x18\x01 \x03(\x05R\rrollbackScope\x12\x1d\n\nnext_child\x18\x02 \x01(\x05R\tnextChildBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.participant_transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_VIEWPARTICIPANTMESSAGE']._loaded_options = None
  _globals['_VIEWPARTICIPANTMESSAGE']._serialized_options = b'\030\001'
  _globals['_DEDUPLICATIONPERIOD']._serialized_start=432
  _globals['_DEDUPLICATIONPERIOD']._serialized_end=546
  _globals['_PARTICIPANTMETADATA']._serialized_start=549
  _globals['_PARTICIPANTMETADATA']._serialized_end=739
  _globals['_ROOTHASHMESSAGE']._serialized_start=742
  _globals['_ROOTHASHMESSAGE']._serialized_end=978
  _globals['_VIEWNODE']._serialized_start=981
  _globals['_VIEWNODE']._serialized_end=1268
  _globals['_VIEWCOMMONDATA']._serialized_start=1271
  _globals['_VIEWCOMMONDATA']._serialized_end=1451
  _globals['_INFORMEE']._serialized_start=1453
  _globals['_INFORMEE']._serialized_end=1509
  _globals['_PARTICIPANTRANDOMNESSLOOKUP']._serialized_start=1511
  _globals['_PARTICIPANTRANDOMNESSLOOKUP']._serialized_end=1606
  _globals['_VIEWPARTICIPANTMESSAGE']._serialized_start=1608
  _globals['_VIEWPARTICIPANTMESSAGE']._serialized_end=1636
  _globals['_INFORMEEMESSAGE']._serialized_start=1639
  _globals['_INFORMEEMESSAGE']._serialized_end=1879
  _globals['_LIGHTTRANSACTIONVIEWTREE']._serialized_start=1882
  _globals['_LIGHTTRANSACTIONVIEWTREE']._serialized_end=2025
  _globals['_FULLINFORMEETREE']._serialized_start=2027
  _globals['_FULLINFORMEETREE']._serialized_end=2123
  _globals['_CREATEDCONTRACT']._serialized_start=2126
  _globals['_CREATEDCONTRACT']._serialized_end=2306
  _globals['_INPUTCONTRACT']._serialized_start=2309
  _globals['_INPUTCONTRACT']._serialized_end=2440
  _globals['_COMMONMETADATA']._serialized_start=2443
  _globals['_COMMONMETADATA']._serialized_end=2615
  _globals['_SUBMITTERMETADATA']._serialized_start=2618
  _globals['_SUBMITTERMETADATA']._serialized_end=3033
  _globals['_SESSIONKEYLOOKUP']._serialized_start=3036
  _globals['_SESSIONKEYLOOKUP']._serialized_end=3263
  _globals['_ENCRYPTEDVIEWMESSAGE']._serialized_start=3266
  _globals['_ENCRYPTEDVIEWMESSAGE']._serialized_end=3816
  _globals['_ACTIONDESCRIPTION']._serialized_start=3819
  _globals['_ACTIONDESCRIPTION']._serialized_end=5018
  _globals['_ACTIONDESCRIPTION_CREATEACTIONDESCRIPTION']._serialized_start=4288
  _globals['_ACTIONDESCRIPTION_CREATEACTIONDESCRIPTION']._serialized_end=4375
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_start=4378
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_end=4753
  _globals['_ACTIONDESCRIPTION_FETCHACTIONDESCRIPTION']._serialized_start=4756
  _globals['_ACTIONDESCRIPTION_FETCHACTIONDESCRIPTION']._serialized_end=4904
  _globals['_ACTIONDESCRIPTION_LOOKUPBYKEYACTIONDESCRIPTION']._serialized_start=4906
  _globals['_ACTIONDESCRIPTION_LOOKUPBYKEYACTIONDESCRIPTION']._serialized_end=5003
  _globals['_VIEWPARTICIPANTDATA']._serialized_start=5021
  _globals['_VIEWPARTICIPANTDATA']._serialized_end=6042
  _globals['_VIEWPARTICIPANTDATA_FREEKEY']._serialized_start=5689
  _globals['_VIEWPARTICIPANTDATA_FREEKEY']._serialized_end=5732
  _globals['_VIEWPARTICIPANTDATA_RESOLVEDKEY']._serialized_start=5735
  _globals['_VIEWPARTICIPANTDATA_RESOLVEDKEY']._serialized_end=5953
  _globals['_VIEWPARTICIPANTDATA_ROLLBACKCONTEXT']._serialized_start=5955
  _globals['_VIEWPARTICIPANTDATA_ROLLBACKCONTEXT']._serialized_end=6042
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetTimeRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetTimeResponse(_message.Message):
    __slots__ = ("current_time",)
    CURRENT_TIME_FIELD_NUMBER: _ClassVar[int]
    current_time: _timestamp_pb2.Timestamp
    def __init__(self, current_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SetTimeRequest(_message.Message):
    __slots__ = ("current_time", "new_time")
    CURRENT_TIME_FIELD_NUMBER: _ClassVar[int]
    NEW_TIME_FIELD_NUMBER: _ClassVar[int]
    current_time: _timestamp_pb2.Timestamp
    new_time: _timestamp_pb2.Timestamp
    def __init__(self, current_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., new_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/admin/user_management_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/admin/user_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import object_meta_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_object__meta__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:com/daml/ledger/api/v1/admin/user_management_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\x1a.com/daml/ledger/api/v1/admin/object_meta.proto\x1a google/protobuf/field_mask.proto\"\xda\x01\n\x04User\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12#\n\rprimary_party\x18\x02 \x01(\tR\x0cprimaryParty\x12%\n\x0eis_deactivated\x18\x03 \x01(\x08R\risDeactivated\x12\x44\n\x08metadata\x18\x04 \x01(\x0b\x32(.com.daml.ledger.api.v1.admin.ObjectMetaR\x08metadata\x12\x30\n\x14identity_provider_id\x18\x05 \x01(\tR\x12identityProviderId\"\xfa\x03\n\x05Right\x12\x63\n\x11participant_admin\x18\x01 \x01(\x0b\x32\x34.com.daml.ledger.api.v1.admin.Right.ParticipantAdminH\x00R\x10participantAdmin\x12L\n\ncan_act_as\x18\x02 \x01(\x0b\x32,.com.daml.ledger.api.v1.admin.Right.CanActAsH\x00R\x08\x63\x61nActAs\x12O\n\x0b\x63\x61n_read_as\x18\x03 \x01(\x0b\x32-.com.daml.ledger.api.v1.admin.Right.CanReadAsH\x00R\tcanReadAs\x12s\n\x17identity_provider_admin\x18\x04 \x01(\x0b\x32\x39.com.daml.ledger.api.v1.admin.Right.IdentityProviderAdminH\x00R\x15identityProviderAdmin\x1a\x12\n\x10ParticipantAdmin\x1a \n\x08\x43\x61nActAs\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x1a!\n\tCanReadAs\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x1a\x17\n\x15IdentityProviderAdminB\x06\n\x04kind\"\x88\x01\n\x11\x43reateUserRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.admin.UserR\x04user\x12;\n\x06rights\x18\x02 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x06rights\"L\n\x12\x43reateUserResponse\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.admin.UserR\x04user\"[\n\x0eGetUserRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x30\n\x14identity_provider_id\x18\x02 \x01(\tR\x12identityProviderId\"I\n\x0fGetUserResponse\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.admin.UserR\x04user\"\x88\x01\n\x11UpdateUserRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.admin.UserR\x04user\x12;\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"L\n\x12UpdateUserResponse\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.admin.UserR\x04user\"^\n\x11\x44\x65leteUserRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x30\n\x14identity_provider_id\x18\x02 \x01(\tR\x12identityProviderId\"\x14\n\x12\x44\x65leteUserResponse\"\x80\x01\n\x10ListUsersRequest\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x30\n\x14identity_provider_id\x18\x04 \x01(\tR\x12identityProviderId\"u\n\x11ListUsersResponse\x12\x38\n\x05users\x18\x01 \x03(\x0b\x32\".com.daml.ledger.api.v1.admin.UserR\x05users\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xa0\x01\n\x16GrantUserRightsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12;\n\x06rights\x18\x02 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x06rights\x12\x30\n\x14identity_provider_id\x18\x03 \x01(\tR\x12identityProviderId\"p\n\x17GrantUserRightsResponse\x12U\n\x14newly_granted_rights\x18\x01 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x12newlyGrantedRights\"\xa1\x01\n\x17RevokeUserRightsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12;\n\x06rights\x18\x02 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x06rights\x12\x30\n\x14identity_provider_id\x18\x03 \x01(\tR\x12identityProviderId\"q\n\x18RevokeUserRightsResponse\x12U\n\x14newly_revoked_rights\x18\x01 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x12newlyRevokedRights\"b\n\x15ListUserRightsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x30\n\x14identity_provider_id\x18\x02 \x01(\tR\x12identityProviderId\"U\n\x16ListUserRightsResponse\x12;\n\x06rights\x18\x01 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x06rights\"\xba\x01\n!UpdateUserIdentityProviderRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12=\n\x1bsource_identity_provider_id\x18\x02 \x01(\tR\x18sourceIdentityProviderId\x12=\n\x1btarget_identity_provider_id\x18\x03 \x01(\tR\x18targetIdentityProviderId\"$\n\"UpdateUserIdentityProviderResponse2\xe5\x08\n\x15UserManagementService\x12o\n\nCreateUser\x12/.com.daml.ledger.api.v1.admin.CreateUserRequest\x1a\x30.com.daml.ledger.api.v1.admin.CreateUserResponse\x12\x66\n\x07GetUser\x12,.com.daml.ledger.api.v1.admin.GetUserRequest\x1a-.com.daml.ledger.api.v1.admin.GetUserResponse\x12o\n\nUpdateUser\x12/.com.daml.ledger.api.v1.admin.UpdateUserRequest\x1a\x30.com.daml.ledger.api.v1.admin.UpdateUserResponse\x12o\n\nDeleteUser\x12/.com.daml.ledger.api.v1.admin.DeleteUserRequest\x1a\x30.com.daml.ledger.api.v1.admin.DeleteUserResponse\x12l\n\tListUsers\x12..com.daml.ledger.api.v1.admin.ListUsersRequest\x1a/.com.daml.ledger.api.v1.admin.ListUsersResponse\x12~\n\x0fGrantUserRights\x12\x34.com.daml.ledger.api.v1.admin.GrantUserRightsRequest\x1a\x35.com.daml.ledger.api.v1.admin.GrantUserRightsResponse\x12\x81\x01\n\x10RevokeUserRights\x12\x35.com.daml.ledger.api.v1.admin.RevokeUserRightsRequest\x1a\x36.com.daml.ledger.api.v1.admin.RevokeUserRightsResponse\x12{\n\x0eListUserRights\x12\x33.com.daml.ledger.api.v1.admin.ListUserRightsRequest\x1a\x34.com.daml.ledger.api.v1.admin.ListUserRightsResponse\x12\xa1\x01\n\x1cUpdateUserIdentityProviderId\x12?.com.daml.ledger.api.v1.admin.UpdateUserIdentityProviderRequest\x1a@.com.daml.ledger.api.v1.admin.UpdateUserIdentityProviderResponseB\xab\x01\n\x1c\x63om.daml.ledger.api.v1.adminB\x1fUserManagementServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.admin.user_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v1.adminB\037UserManagementServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\252\002\034Com.Daml.Ledger.Api.V1.Admin'
  _globals['_USER']._serialized_start=175
  _globals['_USER']._serialized_end=393
  _globals['_RIGHT']._serialized_start=396
  _globals['_RIGHT']._serialized_end=902
  _globals['_RIGHT_PARTICIPANTADMIN']._serialized_start=782
  _globals['_RIGHT_PARTICIPANTADMIN']._serialized_end=800
  _globals['_RIGHT_CANACTAS']._serialized_start=802
  _globals['_RIGHT_CANACTAS']._serialized_end=834
  _globals['_RIGHT_CANREADAS']._serialized_start=836
  _globals['_RIGHT_CANREADAS']._serialized_end=869
  _globals['_RIGHT_IDENTITYPROVIDERADMIN']._serialized_start=871
  _globals['_RIGHT_IDENTITYPROVIDERADMIN']._serialized_end=894
  _globals['_CREATEUSERREQUEST']._serialized_start=905
  _globals['_CREATEUSERREQUEST']._serialized_end=1041
  _globals['_CREATEUSERRESPONSE']._serialized_start=1043
  _globals['_CREATEUSERRESPONSE']._serialized_end=1119
  _globals['_GETUSERREQUEST']._serialized_start=1121
  _globals['_GETUSERREQUEST']._serialized_end=1212
  _globals['_GETUSERRESPONSE']._serialized_start=1214
  _globals['_GETUSERRESPONSE']._serialized_end=1287
  _globals['_UPDATEUSERREQUEST']._serialized_start=1290
  _globals['_UPDATEUSERREQUEST']._serialized_end=1426
  _globals['_UPDATEUSERRESPONSE']._serialized_start=1428
  _globals['_UPDATEUSERRESPONSE']._serialized_end=1504
  _globals['_DELETEUSERREQUEST']._serialized_start=1506
  _globals['_DELETEUSERREQUEST']._serialized_end=1600
  _globals['_DELETEUSERRESPONSE']._serialized_start=1602
  _globals['_DELETEUSERRESPONSE']._serialized_end=1622
  _globals['_LISTUSERSREQUEST']._serialized_start=1625
  _globals['_LISTUSERSREQUEST']._serialized_end=1753
  _globals['_LISTUSERSRESPONSE']._serialized_start=1755
  _globals['_LISTUSERSRESPONSE']._serialized_end=1872
  _globals['_GRANTUSERRIGHTSREQUEST']._serialized_start=1875
  _globals['_GRANTUSERRIGHTSREQUEST']._serialized_end=2035
  _globals['_GRANTUSERRIGHTSRESPONSE']._serialized_start=2037
  _globals['_GRANTUSERRIGHTSRESPONSE']._serialized_end=2149
  _globals['_REVOKEUSERRIGHTSREQUEST']._serialized_start=2152
  _globals['_REVOKEUSERRIGHTSREQUEST']._serialized_end=2313
  _globals['_REVOKEUSERRIGHTSRESPONSE']._serialized_start=2315
  _globals['_REVOKEUSERRIGHTSRESPONSE']._serialized_end=2428
  _globals['_LISTUSERRIGHTSREQUEST']._serialized_start=2430
  _globals['_LISTUSERRIGHTSREQUEST']._serialized_end=2528
  _globals['_LISTUSERRIGHTSRESPONSE']._serialized_start=2530
  _globals['_LISTUSERRIGHTSRESPONSE']._serialized_end=2615
  _globals['_UPDATEUSERIDENTITYPROVIDERREQUEST']._serialized_start=2618
  _globals['_UPDATEUSERIDENTITYPROVIDERREQUEST']._serialized_end=2804
  _globals['_UPDATEUSERIDENTITYPROVIDERRESPONSE']._serialized_start=2806
  _globals['_UPDATEUSERIDENTITYPROVIDERRESPONSE']._serialized_end=2842
  _globals['_USERMANAGEMENTSERVICE']._serialized_start=2845
  _globals['_USERMANAGEMENTSERVICE']._serialized_end=3970
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import participant_repair_service_pb2 as com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/participant/admin/v0/participant_repair_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ParticipantRepairServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Download = channel.unary_stream(
                '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/Download',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.DownloadRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.AcsSnapshotChunk.FromString,
                _registered_method=True)
        self.ExportAcs = channel.unary_stream(
                '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/ExportAcs',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ExportAcsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ExportAcsResponse.FromString,
                _registered_method=True)
        self.Upload = channel.stream_unary(
                '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/Upload',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UploadRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UploadResponse.FromString,
                _registered_method=True)
        self.ImportAcs = channel.stream_unary(
                '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/ImportAcs',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ImportAcsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ImportAcsResponse.FromString,
                _registered_method=True)
        self.PurgeContracts = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/PurgeContracts',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeContractsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeContractsResponse.FromString,
                _registered_method=True)
        self.MigrateDomain = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/MigrateDomain',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.MigrateDomainRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.MigrateDomainResponse.FromString,
                _registered_method=True)
        self.PurgeDeactivatedDomain = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/PurgeDeactivatedDomain',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeDeactivatedDomainRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeDeactivatedDomainResponse.FromString,
                _registered_method=True)
        self.IgnoreEvents = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/IgnoreEvents',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.IgnoreEventsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.IgnoreEventsResponse.FromString,
                _registered_method=True)
        self.UnignoreEvents = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/UnignoreEvents',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UnignoreEventsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UnignoreEventsResponse.FromString,
                _registered_method=True)


class ParticipantRepairServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Download(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportAcs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Upload(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportAcs(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PurgeContracts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MigrateDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PurgeDeactivatedDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IgnoreEvents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnignoreEvents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ParticipantRepairServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Download': grpc.unary_stream_rpc_method_handler(
                    servicer.Download,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.DownloadRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.AcsSnapshotChunk.SerializeToString,
            ),
            'ExportAcs': grpc.unary_stream_rpc_method_handler(
                    servicer.ExportAcs,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ExportAcsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ExportAcsResponse.SerializeToString,
            ),
            'Upload': grpc.stream_unary_rpc_method_handler(
                    servicer.Upload,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UploadRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UploadResponse.SerializeToString,
            ),
            'ImportAcs': grpc.stream_unary_rpc_method_handler(
                    servicer.ImportAcs,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ImportAcsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ImportAcsResponse.SerializeToString,
            ),
            'PurgeContracts': grpc.unary_unary_rpc_method_handler(
                    servicer.PurgeContracts,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeContractsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeContractsResponse.SerializeToString,
            ),
            'MigrateDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.MigrateDomain,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.MigrateDomainRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.MigrateDomainResponse.SerializeToString,
            ),
            'PurgeDeactivatedDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.PurgeDeactivatedDomain,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeDeactivatedDomainRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeDeactivatedDomainResponse.SerializeToString,
            ),
            'IgnoreEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.IgnoreEvents,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.IgnoreEventsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.IgnoreEventsResponse.SerializeToString,
            ),
            'UnignoreEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.UnignoreEvents,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UnignoreEventsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UnignoreEventsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.participant.admin.v0.ParticipantRepairService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.participant.admin.v0.ParticipantRepairService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ParticipantRepairService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/Download',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.DownloadRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.AcsSnapshotChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportAcs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/ExportAcs',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ExportAcsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ExportAcsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Upload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/Upload',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UploadRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UploadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ImportAcs(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/ImportAcs',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ImportAcsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.ImportAcsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PurgeContracts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/PurgeContracts',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeContractsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeContractsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MigrateDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/MigrateDomain',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.MigrateDomainRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.MigrateDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PurgeDeactivatedDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/PurgeDeactivatedDomain',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeDeactivatedDomainRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.PurgeDeactivatedDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IgnoreEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/IgnoreEvents',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.IgnoreEventsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.IgnoreEventsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnignoreEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.ParticipantRepairService/UnignoreEvents',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UnignoreEventsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_participant__repair__service__pb2.UnignoreEventsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListKnownPackagesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListKnownPackagesResponse(_message.Message):
    __slots__ = ("package_details",)
    PACKAGE_DETAILS_FIELD_NUMBER: _ClassVar[int]
    package_details: _containers.RepeatedCompositeFieldContainer[PackageDetails]
    def __init__(self, package_details: _Optional[_Iterable[_Union[PackageDetails, _Mapping]]] = ...) -> None: ...

class PackageDetails(_message.Message):
    __slots__ = ("package_id", "package_size", "known_since", "source_description")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    KNOWN_SINCE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    package_size: int
    known_since: _timestamp_pb2.Timestamp
    source_description: str
    def __init__(self, package_id: _Optional[str] = ..., package_size: _Optional[int] = ..., known_since: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., source_description: _Optional[str] = ...) -> None: ...

class UploadDarFileRequest(_message.Message):
    __slots__ = ("dar_file", "submission_id")
    DAR_FILE_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    dar_file: bytes
    submission_id: str
    def __init__(self, dar_file: _Optional[bytes] = ..., submission_id: _Optional[str] = ...) -> None: ...

class UploadDarFileResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ValidateDarFileRequest(_message.Message):
    __slots__ = ("dar_file", "submission_id")
    DAR_FILE_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    dar_file: bytes
    submission_id: str
    def __init__(self, dar_file: _Optional[bytes] = ..., submission_id: _Optional[str] = ...) -> None: ...

class ValidateDarFileResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .sequencer_initialization_service_pb2 import InitializeSequencerFromGenesisStateRequest, InitializeSequencerFromGenesisStateResponse, InitializeSequencerFromOnboardingStateRequest, InitializeSequencerFromOnboardingStateResponse

__all__ = [
    "SequencerInitializationServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerInitializationServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerInitializationServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerInitializationServiceAsyncStub: ...  # type: ignore
    def InitializeSequencerFromGenesisState(self, __1: _typing.Iterable[InitializeSequencerFromGenesisStateRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[InitializeSequencerFromGenesisStateResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, InitializeSequencerFromGenesisStateResponse]]: ...
    def InitializeSequencerFromOnboardingState(self, __1: _typing.Iterable[InitializeSequencerFromOnboardingStateRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[InitializeSequencerFromOnboardingStateResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, InitializeSequencerFromOnboardingStateResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerInitializationServiceBlockingStub(SequencerInitializationServiceStub):
    def InitializeSequencerFromGenesisState(self, __1: _typing.Iterable[InitializeSequencerFromGenesisStateRequest], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> InitializeSequencerFromGenesisStateResponse: ...
    def InitializeSequencerFromOnboardingState(self, __1: _typing.Iterable[InitializeSequencerFromOnboardingStateRequest], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> InitializeSequencerFromOnboardingStateResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerInitializationServiceAsyncStub(SequencerInitializationServiceStub):
    def InitializeSequencerFromGenesisState(self, __1: _typing.Iterable[InitializeSequencerFromGenesisStateRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, InitializeSequencerFromGenesisStateResponse]: ...  # type: ignore
    def InitializeSequencerFromOnboardingState(self, __1: _typing.Iterable[InitializeSequencerFromOnboardingStateRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, InitializeSequencerFromOnboardingStateResponse]: ...  # type: ignore
